<?php
namespace Gath\Api;

/**
 * Gath endpoint kojeg je moguće pozvati.
 *
 * @package Gath\Api
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gath
 */
final class Endpoint implements EndpointInterface
{
    /** @var string */
    private $name;
    /** @var string */
    private $path;
    /** @var string */
    private $method;
    /** @var string */
    private $responseClass;
    /** @var string */
    private $resultClass;

    /**
     * Endpoint constructor.
     * @param string $name
     * @param array $options
     */
    public function __construct(string $name, array $options = [])
    {
        $this->name = $name;
        $this->path = $options['path'] ?? '/';
        $this->method = $options['method'] ?? 'GET';
        $this->responseClass = $options['response_class'] ?? Info::class;
        $this->resultClass = $options['result_class'] ?? \stdClass::class;
    }

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @return string
     */
    public function getPath(): string
    {
        return $this->path;
    }

    /**
     * Vraća HTTP metodu.
     *
     * @return string
     */
    public function getMethod(): string
    {
        return $this->method;
    }

    /**
     * Vraća klasu objekta kojeg ovaj endpoint vraća.
     *
     * @return string
     */
    public function getResponseClass(): string
    {
        return $this->responseClass;
    }

    /**
     * @return string
     */
    public function getResultClass(): string
    {
        return $this->resultClass;
    }
}