<?php
namespace Gath\Api;

use Interop\Container\ContainerInterface;
use Zend\ServiceManager\Factory\AbstractFactoryInterface;

/**
 * Class EndpointAbstractFactory
 *
 * @package Gath\Api
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gath
 */
final class EndpointAbstractFactory implements AbstractFactoryInterface
{
    /** @var array */
    private $config;

    /**
     * Can the factory create an instance for the service?
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     *
     * @return bool
     */
    public function canCreate(ContainerInterface $container, $requestedName)
    {
        $config = $this->getConfig($container);
        return array_key_exists($requestedName, $config);
    }

    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return EndpointInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $this->getConfig($container)[$requestedName] ?? [];
        return new Endpoint($requestedName, $config);
    }

    /**
     * @param ContainerInterface $container
     * @return array
     */
    private function getConfig(ContainerInterface $container): array
    {
        if (null === $this->config) {
            $this->config = $container->get('config')['gath']['endpoints'] ?? [];
        }

        return $this->config;
    }
}