<?php
namespace Gath;

use Gath\Api\EndpointPluginManager;
use GuzzleHttp\Psr7\Uri;
use Interop\Container\ContainerInterface;
use Zend\Hydrator\HydratorPluginManager;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Gath klijenta.
 *
 * @package Gath
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gath
 */
final class ClientFactory implements FactoryInterface
{
    /**
     * Stvara klijenta.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return ClientInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['gath'] ?? [];

        if (!isset($config['base_uri']) || empty($config['base_uri'])) {
            throw new ServiceNotCreatedException("Ne mogu stvoriti Gath klijenta. Nedostaje postavka 'base_uri'.");
        }

        try {
            $uri = new Uri($config['base_uri']);
        } catch (\Throwable $e) {
            throw new ServiceNotCreatedException(sprintf(
                "Ne mogu stvoriti Uri objekt iz stringa '%s'.", $config['base_uri']
            ), 0, $e);
        }

        $endpoints = $container->get(EndpointPluginManager::class);
        $hydrators = $container->get(HydratorPluginManager::class);

        return new Client($uri, $endpoints, $hydrators);
    }
}