<?php
namespace Gath;

use Gath\Api\EndpointPluginManager;
use Gath\Api\EndpointPluginManagerFactory;
use Zend\Hydrator\HydratorProviderInterface;

/**
 * Pruža konfiguraciju komponente.
 *
 * @package Gath
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gath
 */
final class ConfigProvider implements HydratorProviderInterface
{
    /**
     * Vraća konfiguraciju.
     *
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'dependencies' => $this->getDependencies(),
            'hydrators' => $this->getHydratorConfig(),
            'gath' => [
                'endpoints' => $this->getGathEndpoints(),
            ],
        ];
    }

    /**
     * @return array
     */
    public function getGathEndpoints(): array
    {
        return [
            'api-info' => [
                'path' => '/',
                'response_class' => Api\Info::class,
            ],
        ];
    }

    /**
     * Vraća konfiguraciju containera.
     *
     * @return array
     */
    public function getDependencies(): array
    {
        return [
            'factories' => [
                ClientInterface::class => ClientFactory::class,
                EndpointPluginManager::class => EndpointPluginManagerFactory::class,
            ],
        ];
    }


    /**
     * Provide plugin manager configuration for hydrators.
     *
     * @see    https://docs.zendframework.com/zend-expressive/v3/features/container/config/#the-format
     * @return mixed[][]
     */
    public function getHydratorConfig(): array
    {
        return [
            'aliases' => [
                Api\Endpoint::class => Hydrator\ApiEndpointHydrator::class,
                Api\Info::class => Hydrator\ApiInfoHydrator::class,
                Api\ResultSet::class => Hydrator\ResultSetHydrator::class,
            ],

            'invokables' => [
                Hydrator\ApiEndpointHydrator::class,
                Hydrator\ApiInfoHydrator::class,
                Hydrator\ResultSetHydrator::class,
            ],
        ];
    }
}