<?php
namespace GathTest;

use Ak\Test\AbstractTestCase;
use Gath\Api\ResultSetInterface;
use Gath\ClientInterface;
use Gath\ConfigProvider;
use GathTest\Mock\PriceInfo;

/**
 * Class ClientTest
 *
 * @package GathTest
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gath
 */
final class ClientTest extends AbstractTestCase
{
    protected $providers = [
        \Ak\Hydrator\ConfigProvider::class,
        ConfigProvider::class,
    ];

    protected function getClient(array $endpoints = []): ClientInterface
    {
        $container = $this->getContainer([
            'gath' => [
                'base_uri' => 'http://172.30.60.72:8123',
                'endpoints' => $endpoints,
            ],

            'hydrators' => [
                'aliases' => [
                    Mock\PriceInfo::class => Mock\PriceInfoHydrator::class,
                ],

                'invokables' => [
                    Mock\PriceInfoHydrator::class,
                ],
            ],
        ]);

        return $container->get(ClientInterface::class);
    }

    public function testCanGetInfo()
    {
        $client = $this->getClient();
        $info = $client->getApiInfo();

        $this->assertEquals('1.0.0.20', $info->getVersion());
    }

    public function testCanGetResults()
    {
        $client = $this->getClient([
            'stock' => [
                'path' => '/stock/by-codes',
                'method' => 'POST',
                'result_class' => Mock\PriceInfo::class,
            ],
        ]);

        $response = $client->query('stock', [
            'Codes' => ['31006', 'PERMIN-Z-5/1', '8416'],
        ]);

        $this->assertInstanceOf(ResultSetInterface::class, $response);
        $this->assertInstanceOf(PriceInfo::class, $response->getResults()[0]);
        /** @noinspection PhpUndefinedMethodInspection */
        $this->assertEquals('31006', $response->getResults()[0]->getCode());
    }
}